<%@ Page Language="C#" Title="Story Properties" %>
<%@ Register TagPrefix="cys" Namespace="ChooseYourStory.Web.Controls" Assembly="ChooseYourStory" %>
<%@ Register TagPrefix="adved" Src="SecondaryNavigation.ascx" TagName="SecondaryNavigation" %>
<%@ Register TagPrefix="fck" Src="~/Includes/FckEditor.ascx" TagName="FCKEditor" %>
<%@ Import Namespace="System.Data" %>
<%@ Import Namespace="System.Data.SqlClient" %>
<%@ Import Namespace="ChooseYourStory.Stories.Editing" %>

<script runat="server">

    DataTable coauthorsTable = new DataTable();
    DataTable tagsTable = new DataTable();
    DataRow propertiesRow;
    int StoryId;

    protected override void OnLoad(EventArgs e)
    {
        StoryId = int.Parse(Request.Url.Query.TrimStart('?'));
        EditorHelper.ValidateUserToAdvancedEdit(StoryId, User.Identity.Name);
    }

    protected override void OnLoadComplete(EventArgs e)
    {
        if (!IsPostBack) DataBind();
    }

    public override void DataBind()
    {
        coauthorsTable = EditorHelper.GetCoauthors(StoryId);
        tagsTable = EditorHelper.GetTags(StoryId);
        propertiesRow = EditorHelper.GetStoryProperties(StoryId);

        base.DataBind();
        DifficultyLevel.Items[0].Text = string.Empty; DifficultyLevel.Items[0].Value = string.Empty;
        DifficultyLevel.SelectedValue = EditorHelper.EmptyIf(propertiesRow["Difficulty_Level"]);

        MaturityLevel.Items.Insert(0, new ListItem(string.Empty, string.Empty));
        MaturityLevel.SelectedValue = EditorHelper.EmptyIf(propertiesRow["Maturity_Level"]);

        Category.Items.Insert(0, new ListItem(string.Empty, string.Empty));
        Category.SelectedValue = EditorHelper.EmptyIf(propertiesRow["Category_Id"]);
    }


    /************************************
	 * Button Handlers 
	 ************************************/
    private void EditCoauthors_Click(object sender, EventArgs e)
    {
        SaveChanges();
        Response.Redirect("coauthors.aspx?" + StoryId);
    }

    private void EditTags_Click(object sender, EventArgs e)
    {
        SaveChanges();
        Response.Redirect("tags.aspx?" + StoryId);
    }

    private void ChangeFeatures_Click(object sender, EventArgs e)
    {
        SaveChanges();
        Response.Redirect("editorOptions.aspx?" + StoryId);
    }


    private void SaveChanges_Click(object sender, EventArgs e)
    {
        SaveChanges();
        DataBind();
    }

    private void SecondaryNavigation_BeforeNavigate(object sender, EventArgs e)
    {
        if (((LinkButton)sender).CommandName != "preview")
        {
            SaveChanges();
        } else
        {
            DataBind();
        }
    }

    private void SaveChanges()
    {
        if (!IsValid) return;
        using (SqlCommand cmd = new SqlCommand())
        {
            cmd.Connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ChooseYourStory"].ConnectionString);

            cmd.CommandText = "Story_Editing_UpdateStoryProperties";
            cmd.CommandType = CommandType.StoredProcedure;
            cmd.Parameters.Add("@Story_Id", SqlDbType.Int).Value = StoryId;
            cmd.Parameters.Add("@Story_Title", SqlDbType.VarChar, 100).Value = StoryTitle.Text;
            cmd.Parameters["@Story_Title"].Direction = ParameterDirection.InputOutput;
            cmd.Parameters.Add("@Difficulty_Level", SqlDbType.Int).Value = EditorHelper.NullIf(Request.Form[DifficultyLevel.UniqueID]);
            cmd.Parameters.Add("@Maturity_Level", SqlDbType.Int).Value = EditorHelper.NullIf(Request.Form[MaturityLevel.UniqueID]);
            cmd.Parameters.Add("@Category_Id", SqlDbType.VarChar).Value = EditorHelper.NullIf(Request.Form[Category.UniqueID]);
            cmd.Parameters.Add("@AllowSaves_Indicator", SqlDbType.Char, 1).Value = "Y";
            cmd.Parameters.Add("@AllowPreview_Indicator", SqlDbType.Char, 1).Value = AllowPreview.Checked ? "Y" : "N";
            cmd.Parameters.Add("@Story_Description", SqlDbType.Text).Value = StoryDescription.Value;
            cmd.Parameters.Add("@Short_Description", SqlDbType.VarChar, 80).Value = EditorHelper.NullIf(ShortDescription.Text);

            try
            {
                cmd.Connection.Open();
                cmd.ExecuteNonQuery();
                if (!cmd.Parameters["@Story_Title"].Value.Equals(StoryTitle.Text))
                {
                    ClientScript.RegisterClientScriptBlock(typeof(string),
            "save_alert",
            "alert('The title you entered is already in use and has not been changed. Other changes have been saved, however.');",
            true);
                }
                else
                {
                    ClientScript.RegisterClientScriptBlock(typeof(string),
            "save_alert",
            "alert('Changes have been saved.');",
            true);

                }
            }
            finally
            {
                cmd.Connection.Close();
            }
        }
    }

</script>
<asp:Content ContentPlaceHolderID="HeaderContentPlaceHolder" runat="server">
<style type="text/css">
	.block { display:block;margin-top:10px; }
</style>
</asp:Content>
<asp:Content ContentPlaceHolderID="MainContentPlaceHolder" Runat="Server">
<form runat="server" id="mainForm">
	<div id="maincontent">

		<h1>Advanced Editor &raquo; Properties</h1>
		<adved:SecondaryNavigation runat="server" Selected="properties" OnBeforeNavigate="SecondaryNavigation_BeforeNavigate" />
		<div>&nbsp;&nbsp;<span class="smallerText">Overwhelmed? Make sure to read <a href="/help/articles/article.aspx?ArticleId=3">Chapters, Pages, and Links</a>.</span></div>
		
		<div style="padding-left:15px;">
			<label  class="block">Title</label>
			<asp:TextBox runat="server" ID="StoryTitle" Width="300px" MaxLength="100" Text='<%#HttpUtility.UrlDecode(propertiesRow["Story_Title"] as string)%>' autofocus="true" />
			<asp:RequiredFieldValidator runat="server" ControlToValidate="StoryTitle" Style="display:block" 
				Display="Dynamic" CssClass="error" ErrorMessage="* Required"  ForeColor="" />
			
            <label  class="block">Short Description (Displayed in search) </label>
			<asp:TextBox runat="server" ID="ShortDescription" Width="300px" MaxLength="80" Text='<%#HttpUtility.UrlDecode(propertiesRow["Short_Description"] as string)%>' />

			<label class="block">Description</label>
			<fck:FCKeditor ID="StoryDescription" runat="server" Width="95%" Value='<%#HttpUtility.UrlDecode(propertiesRow["Story_Description"] as string)%>' />
			
			<label class="block">Category</label>
			<asp:DropDownList runat="server" id="Category" 
				DataTextField="Name" DataValueField="CategoryID" 
				DataSource="<%#ChooseYourStory.Categories.CategoryCache.Instance %>" />
			
			<label class="block">Maturity Level</label>
			<asp:DropDownList runat="server" id="MaturityLevel" 
				DataTextField="Description" DataValueField="MaturityLevel" 
				DataSource="<%#ChooseYourStory.Stories.Maturity.MaturityLevelCache.Instance %>" />
			
			<label class="block">Difficulty Level</label>
			<asp:DropDownList runat="server" id="DifficultyLevel" 
				DataTextField="Description" DataValueField="DifficultyLevel" 
				DataSource="<%#ChooseYourStory.Stories.Difficulty.DifficultyLevelCache.Instance %>" />
			
			<label class="block">Coauthors</label>
			<div>
				<asp:Repeater runat="server" DataSource="<%#coauthorsTable%>">
					<ItemTemplate><%# Eval("Coauthor_Username") %></ItemTemplate>
					<SeparatorTemplate>, </SeparatorTemplate>
				</asp:Repeater>
				<asp:Literal runat="server" Text="No coauthors selected" Visible="<%#coauthorsTable.Rows.Count==0%>" />
			</div>
			<asp:LinkButton runat="server" 
				Visible='<%# User.Identity.Name.Equals(propertiesRow["Author_Username"]) %>'
				Style="display:block;"
				OnClick="EditCoauthors_Click"	Text="[edit coauthors]" />
				
			<label class="block">Tags</label>
			<div>
				<asp:Repeater runat="server" DataSource="<%#tagsTable%>">
					<ItemTemplate><%# Eval("Tag") %></ItemTemplate>
					<SeparatorTemplate>, </SeparatorTemplate>
				</asp:Repeater>
				<asp:Literal runat="server" Text="No tags added" Visible="<%#tagsTable.Rows.Count==0%>" />
			</div>
			<asp:LinkButton runat="server" 
				Visible='<%# User.Identity.Name.Equals(propertiesRow["Author_Username"]) %>'
				Style="display:block;"
				OnClick="EditTags_Click" Text="[edit tags]" />
			
			<asp:CheckBox CssClass="block" runat="server" ID="AllowPreview" Text="Allow Sneak Preview"
				Checked='<%# "Y".Equals(propertiesRow["AllowPreview_Indicator"]) %>' />
			<div class="smallerText">
			When this box is checked, this storygame will be visible from your profile page, and users may be able to view the contents of the story before it's published.
                If unchecked, only the author(s) may view it and it will not be shown in your profile.		
			</div>
			
			<label class="block">Editor Options</label>
			<div class="smallerText">
			Use the following link to modify the editor, such as using Advanced Variables and Scripting. 
			<br /><asp:LinkButton runat="server" 
				OnClick="ChangeFeatures_Click"	Text="[change editor features]" />
			</div>			
			
			
			<asp:Button CssClass="block"
				OnClick="SaveChanges_Click"
				runat="server" Text="Save Changes" />

		</div>
		</div>
</form>		
</asp:Content>